# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'spotii.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(750, 485)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.slot_0 = QtWidgets.QStackedWidget(self.centralwidget)
        self.slot_0.setGeometry(QtCore.QRect(90, 130, 96, 224))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.slot_0.sizePolicy().hasHeightForWidth())
        self.slot_0.setSizePolicy(sizePolicy)
        self.slot_0.setStyleSheet("")
        self.slot_0.setObjectName("slot_0")
        self.empty = QtWidgets.QWidget()
        self.empty.setStyleSheet("background-image: url(:/empty_slot/png/slot/spot-slot-empty.png);")
        self.empty.setObjectName("empty")
        self.slot_0.addWidget(self.empty)
        self.detecting = QtWidgets.QWidget()
#        self.detecting.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/detecting 1.png);")
        #self.detecting.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/detecting 1.png);")
        #self.detecting.setStyleSheet(".QWidget{background-image:" + "url(" + ":/slot_1/png/slot/slot_1/detecting 1.png" + ");" + "border:0px}")
        self.detecting.setStyleSheet(".QWidget{background-image:url(:/slot_1/png/slot/slot_1/detecting 1.png);border:0px}")
        self.detecting.setObjectName("detecting")
        self.timer = QtWidgets.QPushButton(self.detecting)
        self.timer.setGeometry(QtCore.QRect(20, 140, 63, 16))
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.timer.setFont(font)
        self.timer.setStyleSheet("QPushButton{background-color: transparent; border:0; color : white}")
        self.timer.setObjectName("timer")
        self.casset_id = QtWidgets.QLabel(self.detecting)
        self.casset_id.setGeometry(QtCore.QRect(0, 200, 101, 21))
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.casset_id.sizePolicy().hasHeightForWidth())
        self.casset_id.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.casset_id.setFont(font)
        self.casset_id.setStyleSheet("QLabel{background-color: transparent; border:0; color : white}")
        self.casset_id.setObjectName("casset_id")
        self.slot_0.addWidget(self.detecting)
        self.warning = QtWidgets.QWidget()
        self.warning.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/warning - 1.png);")
        self.warning.setObjectName("warning")
        self.slot_0.addWidget(self.warning)
        self.positive = QtWidgets.QWidget()
        self.positive.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/positive 1.png);")
        self.positive.setObjectName("positive")
        self.slot_0.addWidget(self.positive)
        self.negative = QtWidgets.QWidget()
        self.negative.setStyleSheet("background-image: url(:/slot_1/png/slot/slot_1/negative - 1.png);")
        self.negative.setObjectName("negative")
        self.slot_0.addWidget(self.negative)
        self.invalid = QtWidgets.QWidget()
        self.invalid.setStyleSheet("QWidget{background-image:url(:/slot_1/png/slot/slot_1/invalid - 1.png);border:0px}")
        self.invalid.setObjectName("invalid")
        self.slot_0.addWidget(self.invalid)
        self.widget = QtWidgets.QWidget(self.centralwidget)
        self.widget.setGeometry(QtCore.QRect(30, 20, 445, 49))
        self.widget.setStyleSheet("background-image: url(:/title_background/png/title/rectangle.png);")
        self.widget.setInputMethodHints(QtCore.Qt.ImhNone)
        self.widget.setObjectName("widget")
        self.gridLayout = QtWidgets.QGridLayout(self.widget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setHorizontalSpacing(5)
        self.gridLayout.setObjectName("gridLayout")
        self.logo = QtWidgets.QLabel(self.widget)
        self.logo.setText("")
        self.logo.setPixmap(QtGui.QPixmap(":/logo/png/title/logo.png"))
        self.logo.setScaledContents(True)
        self.logo.setObjectName("logo")
        self.gridLayout.addWidget(self.logo, 0, 0, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(35, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 1, 1, 1)
        self.help = MyToolButton(self.widget)
        self.help.setEnabled(True)
        font = QtGui.QFont()
        font.setKerning(True)
        self.help.setFont(font)
        self.help.setInputMethodHints(QtCore.Qt.ImhNone)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon.addPixmap(QtGui.QPixmap(":/help/png/title/spot-icons-help-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.help.setIcon(icon)
        self.help.setIconSize(QtCore.QSize(24, 18))
        self.help.setCheckable(True)
        self.help.setPopupMode(QtWidgets.QToolButton.DelayedPopup)
        self.help.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.help.setObjectName("help")
        self.gridLayout.addWidget(self.help, 0, 2, 1, 1)
        self.wifi = MyToolButton(self.widget)
        self.wifi.setEnabled(True)
        self.wifi.setInputMethodHints(QtCore.Qt.ImhNone)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon1.addPixmap(QtGui.QPixmap(":/wifi/png/title/spot-icons-wifi-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.wifi.setIcon(icon1)
        self.wifi.setIconSize(QtCore.QSize(24, 18))
        self.wifi.setCheckable(True)
        self.wifi.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.wifi.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.wifi.setObjectName("wifi")
        self.gridLayout.addWidget(self.wifi, 0, 3, 1, 1)
        self.volume = MyToolButton(self.widget)
        self.volume.setEnabled(True)
        self.volume.setInputMethodHints(QtCore.Qt.ImhNone)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon2.addPixmap(QtGui.QPixmap(":/sound/png/title/spot-icons-sound-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.volume.setIcon(icon2)
        self.volume.setIconSize(QtCore.QSize(24, 18))
        self.volume.setCheckable(True)
        self.volume.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.volume.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.volume.setObjectName("volume")
        self.gridLayout.addWidget(self.volume, 0, 4, 1, 1)
        self.calendar = MyToolButton(self.widget)
        self.calendar.setEnabled(True)
        self.calendar.setInputMethodHints(QtCore.Qt.ImhNone)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/calendar/png/title/spot-icons-calendar-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon3.addPixmap(QtGui.QPixmap(":/calendar/png/title/spot-icons-calendar-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.calendar.setIcon(icon3)
        self.calendar.setIconSize(QtCore.QSize(24, 18))
        self.calendar.setCheckable(True)
        self.calendar.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.calendar.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.calendar.setObjectName("calendar")
        self.gridLayout.addWidget(self.calendar, 0, 5, 1, 1)
        self.setting = MyToolButton(self.widget)
        self.setting.setEnabled(True)
        self.setting.setInputMethodHints(QtCore.Qt.ImhNone)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon4.addPixmap(QtGui.QPixmap(":/setting/png/title/spot-icons-settings-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.setting.setIcon(icon4)
        self.setting.setIconSize(QtCore.QSize(24, 18))
        self.setting.setCheckable(True)
        self.setting.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.setting.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.setting.setObjectName("setting")
        self.gridLayout.addWidget(self.setting, 0, 6, 1, 1)
        self.bluetooth = MyToolButton(self.widget)
        self.bluetooth.setEnabled(True)
        font = QtGui.QFont()
        font.setKerning(True)
        self.bluetooth.setFont(font)
        self.bluetooth.setInputMethodHints(QtCore.Qt.ImhNone)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/bluetooth/png/title/spot-icons-bluetooth-inactive.png"), QtGui.QIcon.Active, QtGui.QIcon.Off)
        icon5.addPixmap(QtGui.QPixmap(":/bluetooth/png/title/spot-icons-bluetooth-active.png"), QtGui.QIcon.Active, QtGui.QIcon.On)
        self.bluetooth.setIcon(icon5)
        self.bluetooth.setIconSize(QtCore.QSize(24, 18))
        self.bluetooth.setCheckable(True)
        self.bluetooth.setPopupMode(QtWidgets.QToolButton.InstantPopup)
        self.bluetooth.setToolButtonStyle(QtCore.Qt.ToolButtonIconOnly)
        self.bluetooth.setObjectName("bluetooth")
        self.gridLayout.addWidget(self.bluetooth, 0, 7, 1, 1)
        self.slot_0.raise_()
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        self.slot_0.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.timer.setText(_translate("MainWindow", "5:30"))
        self.casset_id.setText(_translate("MainWindow", "La0000009"))
from MyToolButton import MyToolButton
import title_rc


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())
